/*
 * Copyright 2009 by Kappich Systemberatung Aachen
 *
 * This file is part of de.kappich.pat.gnd.
 *
 * de.kappich.pat.gnd is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.kappich.pat.gnd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.kappich.pat.gnd.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */
package de.kappich.pat.gnd.linePlugin;

import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.SystemObjectType;
import de.bsvrz.sys.funclib.kappich.annotations.Nullable;
import de.kappich.pat.gnd.displayObjectToolkit.DOTDefinitionDialog;
import de.kappich.pat.gnd.pluginInterfaces.*;
import de.kappich.pat.gnd.properties.ColorProperty;
import de.kappich.pat.gnd.properties.DistanceProperty;
import de.kappich.pat.gnd.properties.Property;
import de.kappich.pat.gnd.properties.StrokeWidthProperty;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Die Selbstbeschreibung des Linien-Plugins.
 *
 * @author Kappich Systemberatung
 * @version $Revision$
 *
 */
public class DOTLinePlugin implements DisplayObjectTypePlugin {

	private static Set<String> _supportedSystemObjectTypePIDs = null;

	/**
	 * Konstruiert eine Selbstbeschreibung des Plugins.
	 */
	public DOTLinePlugin() {
		super();
	}

	@Override
	public String getName() {
		return "Linie";
    }

    @Override
	public DOTDefinitionPanel getPanel( final DOTDefinitionDialog dotDefinitionDialog) {
		return new DefaultDOTDefinitionPanel(new DOTLinePlugin(), dotDefinitionDialog);
    }
//	public DOTDefinitionPanel getPanel( final DOTDefinitionDialog dotDefinitionDialog) {
//		return new DOTLinePanel(dotDefinitionDialog);
//	}

    @Override
	public DisplayObjectType getDisplayObjectType() {
	    return new DOTLine();
    }

    @Override
    public DisplayObjectsInitializer getInitializer() { return new LineInitializer(); }

    @Override
	public DisplayObjectPainter getPainter() {
	    return new DOTLinePainter();
    }

    @Override
	public String[] getPrimitiveFormTypes() {
		return new String[0];
    }

    @Override
    @Nullable
	public Property[] getProperties(@Nullable Object o) {
		Property[] properties = null;
		if ( o == null) {
			properties = new Property[]{
					ColorProperty.getInstance(), DistanceProperty.getInstance(),
					StrokeWidthProperty.getInstance()};
		}
		return properties;
    }

    @Override
	public String getGeometryType() {
		return "typ.linie";
	}

	@Override
	public boolean isSystemObjectTypeSupported(DataModel configuration, SystemObjectType systemObjectType) {
		if ( _supportedSystemObjectTypePIDs == null) {
			initSupportedSystemObjectTypePIDs( configuration);
		}
		return _supportedSystemObjectTypePIDs.contains( systemObjectType.getPid());
    }

	@Override
	public boolean isDynamicsPossible() {
		return true;
	}

	@Override
	public boolean isMapScaleListeningNecessary() {
		return true;
	}

	private void initSupportedSystemObjectTypePIDs(DataModel configuration) {
		final List<SystemObjectType> geoReferenceObjectTypes = new ArrayList<>();
		final SystemObjectType geoReferenceObjectType = configuration.getType(getGeometryType());
		geoReferenceObjectTypes.add( geoReferenceObjectType);
		for( int i = 0; i < geoReferenceObjectTypes.size(); i++) {
			geoReferenceObjectTypes.addAll( geoReferenceObjectTypes.get(i).getSubTypes());
		}
		_supportedSystemObjectTypePIDs = new HashSet<>();
		for ( SystemObjectType systemObjectType : geoReferenceObjectTypes) {
			_supportedSystemObjectTypePIDs.add( systemObjectType.getPid());
		}
    }
}
